### Date Picker

===! "Result"

    ```{.textual path="docs/examples/date_picker_example.py"}
    ```

=== "Source"

    ```python
    --8<-- "docs/examples/date_picker_example.py"
    ```

### Date Range

===! "Result"

    ```{.textual path="docs/examples/date_range_example.py"}
    ```

=== "Source"

    ```python
    --8<-- "docs/examples/date_range_example.py"
    ```

### Date Select

===! "Result"

    ```{.textual path="docs/examples/date_select_example.py"}
    ```

=== "Source"

    ```python
    --8<-- "docs/examples/date_select_example.py"
    ```

### DateTime Range Picker


===! "Result"

    ```{.textual path="docs/examples/dt_range_example.py"}
    ```

=== "Source"

    ```python
    --8<-- "docs/examples/dt_range_example.py"
    ```

### Single Line Picker

===! "Result"

    ```{.textual path="docs/examples/mini_picker_example.py"}
    ```

=== "Source"

    ```python
    --8<-- "docs/examples/mini_picker_example.py"
    ```
